Documentation
¶
Overview ¶
package testutil provides test helper functions
Index ¶
Constants ¶
This section is empty.
Variables ¶
var FailedTopLevelCheckOpts []cmp.Option = []cmp.Option{ cmpopts.EquateEmpty(), cmpopts.SortSlices(lessTopLevelCheck), }
var PkgResultsOpts []cmp.Option = []cmp.Option{ cmpopts.EquateEmpty(), cmpopts.SortSlices(func(package1, package2 *types.PkgResult) bool { return package1.Package.SpdxID < package2.Package.SpdxID }), cmpopts.SortSlices(func(error1, error2 *types.NonConformantField) bool { return error1.Error.ErrorMsg < error2.Error.ErrorMsg }), cmpopts.SortSlices(func(s1, s2 string) bool { return s1 < s2 }), }
Functions ¶
This section is empty.
Types ¶
type FailedTopLevelCheck ¶
FailedTopLevelCheck represents a check that has failed.
This is toplevel version of types.Output.PkgResults. Ideally, the package-level and top-level versions of a list of failed checks are made consistent - either in types.Output or not. This struct and associated function are the first step towards that.
func ExtractFailedTopLevelChecks ¶
func ExtractFailedTopLevelChecks( topLevelChecks []*types.TopLevelCheckResult, ) []FailedTopLevelCheck
ExtractFailedTopLevelChecks returns the failed checks in the input.
Click to show internal directories.
Click to hide internal directories.